from future.utils import raise_from
from requests import HTTPError


class ConfigurationError(Exception):
    pass


class APIError(Exception):
    pass


class ArgumentMissingError(Exception):
    pass


def annotateHTTPError(err):
    if isinstance(err, HTTPError):
        raise_from(APIError(err.response.content), err)
    else:
        raise err



#!/usr/bin/env python
from __future__ import absolute_import
import os
import re
import sys

from codecs import open
from setuptools import setup

github_url = 'https://github.com/chartmogul/chartmogul-python'

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

requires = []
test_requirements = ['mock>=1.0.1', 'requests-mock>=1.3.0']

with open('chartmogul/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('Cannot find version information')

setup(
    name='chartmogul',
    version=version,
    description='Python library for ChartMogul API.',
    long_description='`See documentation on GitHub <' + github_url + '>`_',
    author='Petr Kopac (ChartMogul Ltd.)',
    author_email='petr@chartmogul.com',
    url='https://chartmogul.com',
    download_url = github_url + '/tarball/v' + version,
    packages=['chartmogul'],
    package_data={'': ['LICENSE', 'NOTICE'], 'chartmogul': ['*.pem']},
    package_dir={'chartmogul': 'chartmogul'},
    include_package_data=True,
    install_requires=requires,
    license='MIT',
    zip_safe=False,
    classifiers=(
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Software Development :: Libraries'
    ),
    tests_require=test_requirements,
    test_suite="test",
    extras_require={},
)



# -*- coding: utf-8 -*-
import logging

from .api.config import Config
from .errors import APIError, ConfigurationError, ArgumentMissingError

from .api.ping import Ping
from .api.data_source import DataSource
from .api.plan import Plan
from .api.customer import Customer
from .api.attributes import Attributes
from .api.tags import Tags
from .api.activity import Activity
from .api.subscription import Subscription
from .api.metrics import Metrics
from .api.custom_attrs import CustomAttributes

# Can't merge modules, because of Subscription clash.
import imp


"""
ChartMogul API Python Client

Provides convenient Python bindings for ChartMogul's API.

:copyright: (c) 2017 by ChartMogul Ltd.
:license: MIT, see LICENSE for more details.
"""

__title__ = 'chartmogul'
__version__ = '1.0.0'
__build__ = 0x000000
__author__ = 'ChartMogul Ltd'
__license__ = 'MIT'
__copyright__ = 'Copyright 2017 ChartMogul Ltd'
